@@ -88,6 +88,13 @@ App::Dochazka::REST::Docs::Resources - Documentation of App::Dochazka::REST reso
 
 EOH
 
+# DOCHAZKA_DOCGEN_EPITAPH
+#     the last bit of Resources.pm, which is generated by docgen.sh
+set( 'DOCHAZKA_DOCGEN_EPITAPH', <<'EOH' );
+=cut
+
+1;
+EOH
 
 # -----------------------------------
 # DO NOT EDIT ANYTHING BELOW THIS LINE
